==> open-cluster-management-policy-model-6.8.0-sources.jar: io/fabric8/openclustermanagement/api/model/governancepolicypropagator/policy/v1beta1/PolicyAutomationSpecFluent.java <==
package io.fabric8.openclustermanagement.api.model.governancepolicypropagator.policy.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Object;
import java.lang.String;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class PolicyAutomationSpecFluent<A extends PolicyAutomationSpecFluent<A>> extends BaseFluent<A>{
  public PolicyAutomationSpecFluent() {
  }
  public PolicyAutomationSpecFluent(PolicyAutomationSpec instance) {
    instance = (instance != null ? instance : new PolicyAutomationSpec());

    if (instance != null) {
      this.withAutomationDef(instance.getAutomationDef());
      this.withEventHook(instance.getEventHook());
      this.withMode(instance.getMode());
      this.withPolicyRef(instance.getPolicyRef());
      this.withRescanAfter(instance.getRescanAfter());
      this.withAutomationDef(instance.getAutomationDef());
      this.withEventHook(instance.getEventHook());
      this.withMode(instance.getMode());
      this.withPolicyRef(instance.getPolicyRef());
      this.withRescanAfter(instance.getRescanAfter());
    }
  }
  private AutomationDefBuilder automationDef;
  private String eventHook;
  private String mode;
  private String policyRef;
  private String rescanAfter;
  public AutomationDef buildAutomationDef() {
    return this.automationDef!=null ?this.automationDef.build():null;
  }
  public A withAutomationDef(AutomationDef automationDef) {
    _visitables.get("automationDef").remove(this.automationDef);
    if (automationDef!=null){ this.automationDef= new AutomationDefBuilder(automationDef); _visitables.get("automationDef").add(this.automationDef);} else { this.automationDef = null; _visitables.get("automationDef").remove(this.automationDef); } return (A) this;
  }
  public boolean hasAutomationDef() {
    return this.automationDef != null;
  }
  public AutomationDefNested<A> withNewAutomationDef() {
    return new AutomationDefNested(null);
  }
  public AutomationDefNested<A> withNewAutomationDefLike(AutomationDef item) {
    return new AutomationDefNested(item);
  }
  public AutomationDefNested<A> editAutomationDef() {
    return withNewAutomationDefLike(java.util.Optional.ofNullable(buildAutomationDef()).orElse(null));
  }
  public AutomationDefNested<A> editOrNewAutomationDef() {
    return withNewAutomationDefLike(java.util.Optional.ofNullable(buildAutomationDef()).orElse(new AutomationDefBuilder().build()));
  }
  public AutomationDefNested<A> editOrNewAutomationDefLike(AutomationDef item) {
    return withNewAutomationDefLike(java.util.Optional.ofNullable(buildAutomationDef()).orElse(item));
  }
  public String getEventHook() {
    return this.eventHook;
  }
  public A withEventHook(String eventHook) {
    this.eventHook=eventHook; return (A) this;
  }
  public boolean hasEventHook() {
    return this.eventHook != null;
  }
  public String getMode() {
    return this.mode;
  }
  public A withMode(String mode) {
    this.mode=mode; return (A) this;
  }
  public boolean hasMode() {
    return this.mode != null;
  }
  public String getPolicyRef() {
    return this.policyRef;
  }
  public A withPolicyRef(String policyRef) {
    this.policyRef=policyRef; return (A) this;
  }
  public boolean hasPolicyRef() {
    return this.policyRef != null;
  }
  public String getRescanAfter() {
    return this.rescanAfter;
  }
  public A withRescanAfter(String rescanAfter) {
    this.rescanAfter=rescanAfter; return (A) this;
  }
  public boolean hasRescanAfter() {
    return this.rescanAfter != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PolicyAutomationSpecFluent that = (PolicyAutomationSpecFluent) o;
    if (!java.util.Objects.equals(automationDef, that.automationDef)) return false;

    if (!java.util.Objects.equals(eventHook, that.eventHook)) return false;

    if (!java.util.Objects.equals(mode, that.mode)) return false;

    if (!java.util.Objects.equals(policyRef, that.policyRef)) return false;

    if (!java.util.Objects.equals(rescanAfter, that.rescanAfter)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(automationDef,  eventHook,  mode,  policyRef,  rescanAfter,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (automationDef != null) { sb.append("automationDef:"); sb.append(automationDef + ","); }
    if (eventHook != null) { sb.append("eventHook:"); sb.append(eventHook + ","); }
    if (mode != null) { sb.append("mode:"); sb.append(mode + ","); }
    if (policyRef != null) { sb.append("policyRef:"); sb.append(policyRef + ","); }
    if (rescanAfter != null) { sb.append("rescanAfter:"); sb.append(rescanAfter); }
    sb.append("}");
    return sb.toString();
  }
  public class AutomationDefNested<N> extends AutomationDefFluent<AutomationDefNested<N>> implements Nested<N>{
    AutomationDefNested(AutomationDef item) {
      this.builder = new AutomationDefBuilder(this, item);
    }
    AutomationDefBuilder builder;
    public N and() {
      return (N) PolicyAutomationSpecFluent.this.withAutomationDef(builder.build());
    }
    public N endAutomationDef() {
      return and();
    }
    
  }
  
}

==> open-cluster-management-policy-model-6.9.0-sources.jar: io/fabric8/openclustermanagement/api/model/governancepolicypropagator/policy/v1beta1/PolicyAutomationSpecFluent.java <==
package io.fabric8.openclustermanagement.api.model.governancepolicypropagator.policy.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Object;
import java.lang.String;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class PolicyAutomationSpecFluent<A extends PolicyAutomationSpecFluent<A>> extends BaseFluent<A>{
  public PolicyAutomationSpecFluent() {
  }
  
  public PolicyAutomationSpecFluent(PolicyAutomationSpec instance) {
    this.copyInstance(instance);
  }
  private AutomationDefBuilder automationDef;
  private String eventHook;
  private String mode;
  private String policyRef;
  private String rescanAfter;
  
  protected void copyInstance(PolicyAutomationSpec instance) {
    instance = (instance != null ? instance : new PolicyAutomationSpec());
  
    if (instance != null) {
        this.withAutomationDef(instance.getAutomationDef());
        this.withEventHook(instance.getEventHook());
        this.withMode(instance.getMode());
        this.withPolicyRef(instance.getPolicyRef());
        this.withRescanAfter(instance.getRescanAfter());
        this.withAutomationDef(instance.getAutomationDef());
        this.withEventHook(instance.getEventHook());
        this.withMode(instance.getMode());
        this.withPolicyRef(instance.getPolicyRef());
        this.withRescanAfter(instance.getRescanAfter());
      }
  }
  
  public AutomationDef buildAutomationDef() {
    return this.automationDef!=null ?this.automationDef.build():null;
  }
  
  public A withAutomationDef(AutomationDef automationDef) {
    _visitables.get("automationDef").remove(this.automationDef);
    if (automationDef!=null){ this.automationDef= new AutomationDefBuilder(automationDef); _visitables.get("automationDef").add(this.automationDef);} else { this.automationDef = null; _visitables.get("automationDef").remove(this.automationDef); } return (A) this;
  }
  
  public boolean hasAutomationDef() {
    return this.automationDef != null;
  }
  
  public AutomationDefNested<A> withNewAutomationDef() {
    return new AutomationDefNested(null);
  }
  
  public AutomationDefNested<A> withNewAutomationDefLike(AutomationDef item) {
    return new AutomationDefNested(item);
  }
  
  public AutomationDefNested<A> editAutomationDef() {
    return withNewAutomationDefLike(java.util.Optional.ofNullable(buildAutomationDef()).orElse(null));
  }
  
  public AutomationDefNested<A> editOrNewAutomationDef() {
    return withNewAutomationDefLike(java.util.Optional.ofNullable(buildAutomationDef()).orElse(new AutomationDefBuilder().build()));
  }
  
  public AutomationDefNested<A> editOrNewAutomationDefLike(AutomationDef item) {
    return withNewAutomationDefLike(java.util.Optional.ofNullable(buildAutomationDef()).orElse(item));
  }
  
  public String getEventHook() {
    return this.eventHook;
  }
  
  public A withEventHook(String eventHook) {
    this.eventHook=eventHook; return (A) this;
  }
  
  public boolean hasEventHook() {
    return this.eventHook != null;
  }
  
  public String getMode() {
    return this.mode;
  }
  
  public A withMode(String mode) {
    this.mode=mode; return (A) this;
  }
  
  public boolean hasMode() {
    return this.mode != null;
  }
  
  public String getPolicyRef() {
    return this.policyRef;
  }
  
  public A withPolicyRef(String policyRef) {
    this.policyRef=policyRef; return (A) this;
  }
  
  public boolean hasPolicyRef() {
    return this.policyRef != null;
  }
  
  public String getRescanAfter() {
    return this.rescanAfter;
  }
  
  public A withRescanAfter(String rescanAfter) {
    this.rescanAfter=rescanAfter; return (A) this;
  }
  
  public boolean hasRescanAfter() {
    return this.rescanAfter != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PolicyAutomationSpecFluent that = (PolicyAutomationSpecFluent) o;
    if (!java.util.Objects.equals(automationDef, that.automationDef)) return false;
  
    if (!java.util.Objects.equals(eventHook, that.eventHook)) return false;
  
    if (!java.util.Objects.equals(mode, that.mode)) return false;
  
    if (!java.util.Objects.equals(policyRef, that.policyRef)) return false;
  
    if (!java.util.Objects.equals(rescanAfter, that.rescanAfter)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(automationDef,  eventHook,  mode,  policyRef,  rescanAfter,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (automationDef != null) { sb.append("automationDef:"); sb.append(automationDef + ","); }
    if (eventHook != null) { sb.append("eventHook:"); sb.append(eventHook + ","); }
    if (mode != null) { sb.append("mode:"); sb.append(mode + ","); }
    if (policyRef != null) { sb.append("policyRef:"); sb.append(policyRef + ","); }
    if (rescanAfter != null) { sb.append("rescanAfter:"); sb.append(rescanAfter); }
    sb.append("}");
    return sb.toString();
  }
  public class AutomationDefNested<N> extends AutomationDefFluent<AutomationDefNested<N>> implements Nested<N>{
    AutomationDefNested(AutomationDef item) {
      this.builder = new AutomationDefBuilder(this, item);
    }
    AutomationDefBuilder builder;
    
    public N and() {
      return (N) PolicyAutomationSpecFluent.this.withAutomationDef(builder.build());
    }
    
    public N endAutomationDef() {
      return and();
    }
    
  
  }

}
